@@ -5,30 +5,30 @@ use crate::error;
 
 pub async fn get(
     client: &web::Data<Client>,
-    url: &String,
+    url: &str,
 ) -> Result<serde_json::Value, error::FunesError> {
-    Ok(client
+    client
         .get(url)
         .send()
         .await
-        .map_err(error::FunesError::RequestError)?
+        .map_err(error::FunesError::Request)?
         .json()
         .await
-        .map_err(error::FunesError::RequestError)?)
+        .map_err(error::FunesError::Request)
 }
 
 pub async fn post(
     client: &web::Data<Client>,
-    url: &String,
+    url: &str,
     payload: &serde_json::Value,
 ) -> Result<serde_json::Value, error::FunesError> {
-    Ok(client
+    client
         .post(url)
         .json(payload)
         .send()
         .await
-        .map_err(error::FunesError::RequestError)?
+        .map_err(error::FunesError::Request)?
         .json()
         .await
-        .map_err(error::FunesError::RequestError)?)
+        .map_err(error::FunesError::Request)
 }
